@@ -45,6 +45,7 @@ from zope.viewlet import viewlet
 from zope.i18n.interfaces.locales import ICollator
 from zope.i18n import translate
 
+import zc.resourcelibrary
 from zc.table.column import GetterColumn
 from z3c.form import form as z3cform
 from z3c.form import field, button
@@ -616,6 +617,9 @@ class GradebookOverview(SectionFinder):
         else:
             updateGrades = ''
 
+        if ICommentScoreSystem.providedBy(insecure_activity.scoresystem):
+            zc.resourcelibrary.need("fckeditor")
+
         return {
             'linked_source': None,
             'scorable': scorable,
