@@ -77,4 +77,4 @@ def fixDecimal():
     See http://mail.python.org/pipermail/python-dev/2008-July/081420.html
     """
     import decimal
-    decimal.Decimal.__repr__ = lambda s: 'Decimal("%s")' % str(s)
+    decimal.Decimal.__repr__ = lambda s: "Decimal('%s')" % str(s)
